@@ -259,15 +259,15 @@ CPU cores.")
         )
         .arg(
             Arg::new("compression")
-                .help("Deflate compression level (1-12)")
+                .help("Deflate compression level (0-12)")
                 .long_help("\
-Deflate compression level (1-12) for main compression trials. The levels here are defined \
+Deflate compression level (0-12) for main compression trials. The levels here are defined \
 by the libdeflate compression library.
 
 The default value depends on the optimization level preset.")
                 .long("zc")
                 .value_name("level")
-                .value_parser(1..=12)
+                .value_parser(0..=12)
                 .conflicts_with("zopfli"),
         )
         .arg(
@@ -337,6 +337,17 @@ Recommended use is with '-o max' and '--fast'.")
                 .long("zopfli")
                 .action(ArgAction::SetTrue),
         )
+        .arg(
+            Arg::new("iterations")
+                .help("Number of Zopfli iterations")
+                .long_help("\
+Set the number of iterations to use for Zopfli compression. Using fewer iterations may \
+speed up compression for large files. This option requires '--zopfli' to be set.")
+                .long("zi")
+                .default_value("15")
+                .value_parser(1..=255)
+                .requires("zopfli"),
+        )
         .arg(
             Arg::new("timeout")
                 .help("Maximum amount of time to spend on optimizations")
