@@ -107,7 +107,7 @@ fn collect_files(
     let mut in_out_pairs = Vec::new();
     let allow_stdin = top_level && files.len() == 1;
     for input in files {
-        let using_stdin = allow_stdin && input.to_str().map_or(false, |p| p == "-");
+        let using_stdin = allow_stdin && input.to_str() == Some("-");
         if !using_stdin && input.is_dir() {
             if recursive {
                 match input.read_dir() {
@@ -324,12 +324,14 @@ fn parse_opts_into_struct(
         opts.strip = StripChunks::Safe;
     }
 
+    #[cfg(feature = "zopfli")]
     if matches.get_flag("zopfli") {
-        #[cfg(feature = "zopfli")]
-        if let Some(iterations) = NonZeroU8::new(15) {
-            opts.deflate = Deflaters::Zopfli { iterations };
-        }
-    } else if let (Deflaters::Libdeflater { compression }, Some(x)) =
+        let iterations = *matches.get_one::<i64>("iterations").unwrap();
+        opts.deflate = Deflaters::Zopfli {
+            iterations: NonZeroU8::new(iterations as u8).unwrap(),
+        };
+    }
+    if let (Deflaters::Libdeflater { compression }, Some(x)) =
         (&mut opts.deflate, matches.get_one::<i64>("compression"))
     {
         *compression = *x as u8;
